package com.springpoc.devicemanagement.service.impl;


import com.springpoc.devicemanagement.dto.DeviceDTO;
import com.springpoc.devicemanagement.dto.MerchantDeviceAssReq;
import com.springpoc.devicemanagement.model.MerchantDeviceAss;
import com.springpoc.devicemanagement.repo.DeviceRepository;
import com.springpoc.devicemanagement.repo.MerchantDeviceAssociationRepository;
import com.springpoc.devicemanagement.repo.UserRepository;
import com.springpoc.devicemanagement.service.DeviceService;
import com.springpoc.devicemanagement.utils.DeviceMapper;
import com.springpoc.userservice.exception.CustomException;

import org.bson.types.ObjectId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

@Service
public class DeviceServiceImpl implements DeviceService {
    private final UserRepository userRepository;
    @Autowired
    DeviceRepository deviceRepository;


    @Autowired
    MerchantDeviceAssociationRepository merchantDeviceAssociationRepository;


    public DeviceServiceImpl(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

    @Override
    public Mono<DeviceDTO> saveDeviceDetails(Mono<DeviceDTO> deviceDTOMono) {
        return DeviceMapper.mapToDevice(deviceDTOMono)
                .flatMap(device -> deviceRepository.save(device))
                .map(devices -> DeviceMapper.mapToDeviceDTO(devices))
                .switchIfEmpty(Mono.error(new RuntimeException("Invalid details.")));
    }

    @Override
    public Mono<String> deleteDeviceDetails() {
        return deviceRepository.deleteAll()
                .thenReturn("Device details deleted successfully.");
    }

    @Override
    public Mono<String> createAssociation(MerchantDeviceAssReq merchantdeviceassociation) {
        ObjectId deviceID = merchantdeviceassociation.getDevice_id();
        ObjectId merchant_id = merchantdeviceassociation.getMerchant_id();
        if (merchant_id == null && deviceID == null) {
            return Mono.error(new CustomException("Merchant Id or device Id is required."));
        } else {
            return userRepository.findById(merchant_id)
                    .flatMap(user -> {
                        return deviceRepository.findById(deviceID)
                                .flatMap(device -> {
                                    // Check if the OTP matches the predefined OTP
                                    if (!user.getId().equals(merchant_id) && !device.getId().equals(deviceID)) {
                                        return Mono.error(new CustomException("Merchant id or Device  is not valid"));
                                    } else if (!user.getUserType().equalsIgnoreCase("Merchant")) {
                                        return Mono.error(new CustomException("User should merchant user."));
                                    } else {
                                        MerchantDeviceAss merchantDeviceAss =
                                                MerchantDeviceAss.builder()
                                                        .device_id(deviceID)
                                                        .merchant_id(merchant_id)
                                                        .status("Assigned")
                                                        .build();
                                        return merchantDeviceAssociationRepository.save(merchantDeviceAss)
                                                .thenReturn("Device and Merchant Association done successfully.");
                                    }
                                }).switchIfEmpty(Mono.error(new CustomException("Device Id is not Valid.")));
                    })
                    .switchIfEmpty(Mono.error(new CustomException("Merchant Id is not Valid.")));
        }
    }

}