package com.springpo.loginservice.controller;


import com.springpo.loginservice.dto.LoginOutUserRequest;
import com.springpo.loginservice.dto.LoginUserRequest;
import com.springpo.loginservice.model.LoginUser;
import com.springpo.loginservice.service.LoginService;

import com.springpoc.userservice.model.User;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.io.UnsupportedEncodingException;

@RestController
@RequestMapping("/login")
public class LoginController {


    @Autowired
    LoginService loginService;

    @PostMapping("/validateOtpAndGeneratePass")
    public Mono<String> validateOtpAndGeneratePass(@RequestBody LoginUserRequest loginUserRequest) {
        return loginService.validateOtpAndGeneratePass(loginUserRequest);
    }

  /*  @PostMapping("/createUserEntryLogin")
    public Void createUserEntryLogin(@Validated @RequestBody User user) {
         loginService.fetchUserAndSave(user);
        return null;
    }*/

    @PostMapping("/createAllUsersEntryLogin")
    public Flux<ResponseEntity<LoginUser>> createUserEntryLogin(@Validated @RequestBody Flux<User> users) {
        return loginService.fetchAllUsersAndSave(users)
                .map(ResponseEntity::ok)
                .onErrorResume(e -> Flux.just(ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                        .body(null))); // or handle error with a proper error response

    }

    @PostMapping("/authenticatePassword")
    public Mono<ResponseEntity<User>> authenticatePassword(@RequestBody LoginUserRequest loginUserRequest) {
        return loginService.authenticatePassword(loginUserRequest);
    }

    @DeleteMapping(path = "/delete/{email}", produces = MediaType.APPLICATION_JSON_VALUE)
    public Mono<String> deleteByEmailId(@PathVariable String email) {
        return loginService.deleteByEmailId(email);
    }

    @PostMapping(path = "/logoutUser", produces = MediaType.APPLICATION_JSON_VALUE)
    public Mono<String> logoutUser(@RequestBody LoginOutUserRequest LoginOutUserRequest) {

        return loginService.logoutUser(LoginOutUserRequest);
    }
}
