package com.springpo.loginservice.utils;


import com.springpo.loginservice.dto.LoginDTO;
import com.springpo.loginservice.model.LoginUser;
import com.springpoc.userservice.dto.UserDTO;
import com.springpoc.userservice.model.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.support.SendResult;
import reactor.core.publisher.Mono;

import java.util.concurrent.CompletableFuture;

public class LoginMapper {
    @Value("${spring.kafka.login.topic}")
    private static String kafkaTopic;

    @Value("${spring.kafka.password.topic}")
    private static String kafkaPasswordTopic;

    @Autowired
    private static KafkaTemplate<String, LoginUser> kafkaTemplate;
   /* @Autowired
    private static KafkaTemplate<String, String> kafkaTemplate1;*/

    public static LoginUser mapUserToLoginUsers(User user){
       // String generatedPassword = LoginMapper.createPassword(user);
       return LoginUser.builder()
                .id(user.getId())
                .loginFlag(Boolean.FALSE)
                .logoutFlag(Boolean.FALSE)
                .otp(ConstantsUtils.otp)
                .email(user.getEmail())
                .phNo(user.getPhNo())
                .userStatus(user.getUserStatus())
                .userType(user.getUserType())
                .password(null)
                .createdBy(user.getCreatedBy())
                .updatedBy(user.getUpdatedBy())
                .build();
    }

    public static Mono<LoginUser> saveUserLoginTopic(LoginUser loginUser) {
        CompletableFuture<SendResult<String, LoginUser>> completableFuture = kafkaTemplate.send(kafkaTopic, loginUser);
        return Mono.fromFuture(completableFuture)
                .map(sendResult -> sendResult.getProducerRecord().value());
    }

 /*   public static Mono<String> savePasswordInTopic(String password) {
        CompletableFuture<SendResult<String, String>> completableFuture = kafkaTemplate1.send(kafkaPasswordTopic, password);
        return Mono.fromFuture(completableFuture)
                .map(sendResult -> sendResult.getProducerRecord().value());
    }*/
    public static String createPassword(User user) {
        String firstNamePart = user.getFirstName().substring(0, 2);
        String phoneNumberPart = user.getPhNo().substring(3, 7);
        String lastNamePart = user.getLastName().substring(user.getLastName().length() - 2);
        return firstNamePart + phoneNumberPart + lastNamePart;
    }

}
