package com.springpoc.userservice.controller;

import com.springpoc.userservice.dto.UserDTO;
import com.springpoc.userservice.model.User;

import com.springpoc.userservice.service.UserService;
import jakarta.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.bson.types.ObjectId;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.util.List;
import java.util.UUID;

@RestController
@RequestMapping("/user")
@Slf4j
public class UserController {

    @Autowired
    UserService userService;

    private static Logger logger = LoggerFactory.getLogger(UserController.class);

    @PostMapping("/createUser")
    public Mono<ResponseEntity<UserDTO>> createUser(@Validated @RequestBody Mono<User> user) {
        log.info("inside the controller, createUser method ");
        return userService.createUser(user);
    }

    @PostMapping("/createAllUsers")
    Flux<User> createAllUsers(@Validated @RequestBody Flux<User> userFlux){
        return userService.createAllUsers(userFlux);
    }
    @GetMapping("/searchUser/{email}")
    Mono<ResponseEntity<User>> searchUser(@Validated @PathVariable("email") String email){
       return userService.findByEmail(email);
    }

    @PatchMapping("/updateUser")
    Mono<ResponseEntity<User>> updateUser(@Validated @RequestBody Mono<User> userMono){
        return userService.updateUser(userMono);
    }

    @DeleteMapping(path="/delete/{email}", produces= MediaType.APPLICATION_JSON_VALUE)
    public Mono<String> deleteByEmailId(@Valid @RequestBody String email) {
        return userService.deleteByEmailId(email);
    }
}
