package com.springpoc.userservice.model;

import jakarta.persistence.*;
import jakarta.validation.constraints.Email;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Pattern;
import lombok.*;
import org.bson.types.ObjectId;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

import java.time.LocalDateTime;
import java.util.UUID;

@Getter
@Setter
@ToString
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Document(collection = "user-details")
public class User {

    @Id
    private ObjectId id;

    @Column
    @NotBlank(message = "User first name cannot be blank")
    private String firstName;
    @Column
    @NotBlank(message = "User last name cannot be blank")
    private String lastName;

    @NotBlank(message = "Phone number is required")
    @Pattern(regexp = "^\\+(?:[0-9] ?){6,14}[0-9]$", message = "Invalid phone number format")
    @Column
    private String phNo;

    @Email(message = "Invalid email format")
    @NotBlank(message = "Email is required")
    @Column(unique = true)
    private String email;
    @Column
    private UserAddress address;
    @Column
    @NotBlank(message = "User userType cannot be blank")
    private String userType;
    @Column
    @NotBlank(message = "User status cannot be blank")
    private String userStatus;
    @Column
    @NotBlank(message = "created By User cannot be blank")
    private String createdBy;
    @Column
    private LocalDateTime createdTime;
    @Column
    private String updatedBy;
    @Column
    private LocalDateTime updatedTime;
}